==> openshift-model-6.9.0-sources.jar: io/fabric8/openshift/api/model/HelmChartRepositorySpecFluent.java <==
package io.fabric8.openshift.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class HelmChartRepositorySpecFluent<A extends HelmChartRepositorySpecFluent<A>> extends BaseFluent<A>{
  public HelmChartRepositorySpecFluent() {
  }
  
  public HelmChartRepositorySpecFluent(HelmChartRepositorySpec instance) {
    this.copyInstance(instance);
  }
  private ConnectionConfigBuilder connectionConfig;
  private String description;
  private Boolean disabled;
  private String name;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(HelmChartRepositorySpec instance) {
    instance = (instance != null ? instance : new HelmChartRepositorySpec());
  
    if (instance != null) {
        this.withConnectionConfig(instance.getConnectionConfig());
        this.withDescription(instance.getDescription());
        this.withDisabled(instance.getDisabled());
        this.withName(instance.getName());
        this.withConnectionConfig(instance.getConnectionConfig());
        this.withDescription(instance.getDescription());
        this.withDisabled(instance.getDisabled());
        this.withName(instance.getName());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public ConnectionConfig buildConnectionConfig() {
    return this.connectionConfig!=null ?this.connectionConfig.build():null;
  }
  
  public A withConnectionConfig(ConnectionConfig connectionConfig) {
    _visitables.get("connectionConfig").remove(this.connectionConfig);
    if (connectionConfig!=null){ this.connectionConfig= new ConnectionConfigBuilder(connectionConfig); _visitables.get("connectionConfig").add(this.connectionConfig);} else { this.connectionConfig = null; _visitables.get("connectionConfig").remove(this.connectionConfig); } return (A) this;
  }
  
  public boolean hasConnectionConfig() {
    return this.connectionConfig != null;
  }
  
  public ConnectionConfigNested<A> withNewConnectionConfig() {
    return new ConnectionConfigNested(null);
  }
  
  public ConnectionConfigNested<A> withNewConnectionConfigLike(ConnectionConfig item) {
    return new ConnectionConfigNested(item);
  }
  
  public ConnectionConfigNested<A> editConnectionConfig() {
    return withNewConnectionConfigLike(java.util.Optional.ofNullable(buildConnectionConfig()).orElse(null));
  }
  
  public ConnectionConfigNested<A> editOrNewConnectionConfig() {
    return withNewConnectionConfigLike(java.util.Optional.ofNullable(buildConnectionConfig()).orElse(new ConnectionConfigBuilder().build()));
  }
  
  public ConnectionConfigNested<A> editOrNewConnectionConfigLike(ConnectionConfig item) {
    return withNewConnectionConfigLike(java.util.Optional.ofNullable(buildConnectionConfig()).orElse(item));
  }
  
  public String getDescription() {
    return this.description;
  }
  
  public A withDescription(String description) {
    this.description=description; return (A) this;
  }
  
  public boolean hasDescription() {
    return this.description != null;
  }
  
  public Boolean getDisabled() {
    return this.disabled;
  }
  
  public A withDisabled(Boolean disabled) {
    this.disabled=disabled; return (A) this;
  }
  
  public boolean hasDisabled() {
    return this.disabled != null;
  }
  
  public String getName() {
    return this.name;
  }
  
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  
  public boolean hasName() {
    return this.name != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HelmChartRepositorySpecFluent that = (HelmChartRepositorySpecFluent) o;
    if (!java.util.Objects.equals(connectionConfig, that.connectionConfig)) return false;
  
    if (!java.util.Objects.equals(description, that.description)) return false;
  
    if (!java.util.Objects.equals(disabled, that.disabled)) return false;
  
    if (!java.util.Objects.equals(name, that.name)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(connectionConfig,  description,  disabled,  name,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (connectionConfig != null) { sb.append("connectionConfig:"); sb.append(connectionConfig + ","); }
    if (description != null) { sb.append("description:"); sb.append(description + ","); }
    if (disabled != null) { sb.append("disabled:"); sb.append(disabled + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
  public A withDisabled() {
    return withDisabled(true);
  }
  public class ConnectionConfigNested<N> extends ConnectionConfigFluent<ConnectionConfigNested<N>> implements Nested<N>{
    ConnectionConfigNested(ConnectionConfig item) {
      this.builder = new ConnectionConfigBuilder(this, item);
    }
    ConnectionConfigBuilder builder;
    
    public N and() {
      return (N) HelmChartRepositorySpecFluent.this.withConnectionConfig(builder.build());
    }
    
    public N endConnectionConfig() {
      return and();
    }
    
  
  }

}

==> openshift-model-6.9.1-sources.jar: io/fabric8/openshift/api/model/HelmChartRepositorySpecFluent.java <==
package io.fabric8.openshift.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class HelmChartRepositorySpecFluent<A extends HelmChartRepositorySpecFluent<A>> extends BaseFluent<A>{
  public HelmChartRepositorySpecFluent() {
  }
  
  public HelmChartRepositorySpecFluent(HelmChartRepositorySpec instance) {
    this.copyInstance(instance);
  }
  private ConnectionConfigBuilder connectionConfig;
  private String description;
  private Boolean disabled;
  private String name;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(HelmChartRepositorySpec instance) {
    instance = (instance != null ? instance : new HelmChartRepositorySpec());
    if (instance != null) {
          this.withConnectionConfig(instance.getConnectionConfig());
          this.withDescription(instance.getDescription());
          this.withDisabled(instance.getDisabled());
          this.withName(instance.getName());
          this.withConnectionConfig(instance.getConnectionConfig());
          this.withDescription(instance.getDescription());
          this.withDisabled(instance.getDisabled());
          this.withName(instance.getName());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public ConnectionConfig buildConnectionConfig() {
    return this.connectionConfig != null ? this.connectionConfig.build() : null;
  }
  
  public A withConnectionConfig(ConnectionConfig connectionConfig) {
    this._visitables.remove(this.connectionConfig);
    if (connectionConfig != null) {
        this.connectionConfig = new ConnectionConfigBuilder(connectionConfig);
        this._visitables.get("connectionConfig").add(this.connectionConfig);
    } else {
        this.connectionConfig = null;
        this._visitables.get("connectionConfig").remove(this.connectionConfig);
    }
    return (A) this;
  }
  
  public boolean hasConnectionConfig() {
    return this.connectionConfig != null;
  }
  
  public ConnectionConfigNested<A> withNewConnectionConfig() {
    return new ConnectionConfigNested(null);
  }
  
  public ConnectionConfigNested<A> withNewConnectionConfigLike(ConnectionConfig item) {
    return new ConnectionConfigNested(item);
  }
  
  public ConnectionConfigNested<A> editConnectionConfig() {
    return withNewConnectionConfigLike(java.util.Optional.ofNullable(buildConnectionConfig()).orElse(null));
  }
  
  public ConnectionConfigNested<A> editOrNewConnectionConfig() {
    return withNewConnectionConfigLike(java.util.Optional.ofNullable(buildConnectionConfig()).orElse(new ConnectionConfigBuilder().build()));
  }
  
  public ConnectionConfigNested<A> editOrNewConnectionConfigLike(ConnectionConfig item) {
    return withNewConnectionConfigLike(java.util.Optional.ofNullable(buildConnectionConfig()).orElse(item));
  }
  
  public String getDescription() {
    return this.description;
  }
  
  public A withDescription(String description) {
    this.description = description;
    return (A) this;
  }
  
  public boolean hasDescription() {
    return this.description != null;
  }
  
  public Boolean getDisabled() {
    return this.disabled;
  }
  
  public A withDisabled(Boolean disabled) {
    this.disabled = disabled;
    return (A) this;
  }
  
  public boolean hasDisabled() {
    return this.disabled != null;
  }
  
  public String getName() {
    return this.name;
  }
  
  public A withName(String name) {
    this.name = name;
    return (A) this;
  }
  
  public boolean hasName() {
    return this.name != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HelmChartRepositorySpecFluent that = (HelmChartRepositorySpecFluent) o;
    if (!java.util.Objects.equals(connectionConfig, that.connectionConfig)) return false;
    if (!java.util.Objects.equals(description, that.description)) return false;
    if (!java.util.Objects.equals(disabled, that.disabled)) return false;
    if (!java.util.Objects.equals(name, that.name)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(connectionConfig,  description,  disabled,  name,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (connectionConfig != null) { sb.append("connectionConfig:"); sb.append(connectionConfig + ","); }
    if (description != null) { sb.append("description:"); sb.append(description + ","); }
    if (disabled != null) { sb.append("disabled:"); sb.append(disabled + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
  public A withDisabled() {
    return withDisabled(true);
  }
  public class ConnectionConfigNested<N> extends ConnectionConfigFluent<ConnectionConfigNested<N>> implements Nested<N>{
    ConnectionConfigNested(ConnectionConfig item) {
      this.builder = new ConnectionConfigBuilder(this, item);
    }
    ConnectionConfigBuilder builder;
    
    public N and() {
      return (N) HelmChartRepositorySpecFluent.this.withConnectionConfig(builder.build());
    }
    
    public N endConnectionConfig() {
      return and();
    }
    
  
  }

}
